OuterRewardMerkleProof

Type Alias OuterRewardMerkleProof 

type OuterRewardMerkleProof = MerkleProof<KeccakNode, OuterIndex, KeccakNode, REWARD_MERKLE_TREE_V2_ARITY>;
Membership proof for an inner tree root in the outer tree.

Internal type used when patching inner proofs with outer proofs. Proves that a specific inner tree root exists at a specific partition index.

Aliased Type

struct OuterRewardMerkleProof {
    pub pos: OuterIndex,
    pub proof: Vec<MerkleNode<KeccakNode, OuterIndex, KeccakNode>>,
}

Fields

pos: OuterIndex

Proof of inclusion for element at index pos

proof: Vec<MerkleNode<KeccakNode, OuterIndex, KeccakNode>>

Nodes of proof path, from root to leaf