pub type RewardMerkleProof = MerkleProof<RewardAmount, RewardAccountV2, KeccakNode, REWARD_MERKLE_TREE_V2_ARITY>;Expand description
Membership proof for an account’s balance in the tree.
Proves that a specific account has a specific balance at a given tree root. Contains the merkle path from leaf to root with all sibling hashes needed for verification. This proof can be verified on-chain in Solidity.
Aliased Type
pub struct RewardMerkleProof {
pub pos: RewardAccountV2,
pub proof: Vec<MerkleNode<RewardAmount, RewardAccountV2, KeccakNode>>,
}Fields
pos: RewardAccountV2Proof of inclusion for element at index pos
proof: Vec<MerkleNode<RewardAmount, RewardAccountV2, KeccakNode>>Nodes of proof path, from root to leaf